==> apache-cxf-3.6.8-src.zip: apache-cxf-3.6.8-src/tools/javato/ws/src/test/java/org/apache/cxf/tools/fortest/withannotation/doc/Stock12Impl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.tools.fortest.withannotation.doc;

import javax.jws.WebMethod;
import javax.jws.WebService;
import javax.xml.ws.BindingType;
import javax.xml.ws.RequestWrapper;
import javax.xml.ws.ResponseWrapper;
import javax.xml.ws.soap.SOAPBinding;

@WebService
@BindingType (value = SOAPBinding.SOAP12HTTP_BINDING)
public class Stock12Impl implements Stock {
    @WebMethod
    @RequestWrapper(localName = "xXx",
                    className = "org.apache.cxf.tools.fortest.withannotation.doc.jaxws.GetPrice")
    @ResponseWrapper(localName = "zZz",
                     className = "org.apache.cxf.tools.fortest.withannotation.doc.jaxws.GetPriceResponse")
    public float getPrice(String tickerSymbol) {
        return 0;
    }
}

==> apache-cxf-4.1.4-src.zip: apache-cxf-4.1.4-src/tools/javato/ws/src/test/java/org/apache/cxf/tools/fortest/withannotation/doc/Stock12Impl.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.tools.fortest.withannotation.doc;

import jakarta.jws.WebMethod;
import jakarta.jws.WebService;
import jakarta.xml.ws.BindingType;
import jakarta.xml.ws.RequestWrapper;
import jakarta.xml.ws.ResponseWrapper;
import jakarta.xml.ws.soap.SOAPBinding;

@WebService
@BindingType (value = SOAPBinding.SOAP12HTTP_BINDING)
public class Stock12Impl implements Stock {
    @WebMethod
    @RequestWrapper(localName = "xXx",
                    className = "org.apache.cxf.tools.fortest.withannotation.doc.jaxws.GetPrice")
    @ResponseWrapper(localName = "zZz",
                     className = "org.apache.cxf.tools.fortest.withannotation.doc.jaxws.GetPriceResponse")
    public float getPrice(String tickerSymbol) {
        return 0;
    }
}
